(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

open OCAAccount

module TZ = CalendarLib.Time_Zone

let users = 
  [
    0, "Mr Foo", TZ.UTC, "en", "admin1";
    1, "Mr Bar", TZ.UTC, "en", "admin2";
    2, "Mr Baz", TZ.UTC, "fr", "user1";
    3, "Mr Tux", TZ.UTC, "fr", "user2";
  ]

let with_id ~ctxt f  =
  match ctxt with
    | `Live _ ->
        ()
    | `Stub id ->
        f id

let populate stub_id = 
  List.iter 
    (fun (id, real_name, tz, lang, uname) ->
       OCAStubData.add 
         OCAAccount.stub_data
         stub_id
         {
           accnt_id        = id;
           accnt_real_name = real_name;
           accnt_tz        = tz;
           accnt_lang      = lang;
           accnt_unix_id   = id + 20000;
           accnt_unix_name = uname;
         })
    users  

let session_add sess stub_id =
  OCAStubData.add
    OCASession.stub_data
    stub_id
    sess

let session_remove sess stub_id =
  OCAStubData.filter 
    OCASession.stub_data 
    stub_id
    (fun sess' ->
       OCASession.compare sess sess' <> 0)
