(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

(** Manage timezone, as found in FusionForge DB
    @author Sylvain Le Gall
  *)

module TZ = CalendarLib.Time_Zone
module MapString = Map.Make(String)

let of_string =
  let table = 
    [
      "GMT", TZ.UTC;
      "UTC", TZ.UTC;
      "America/New_York",     TZ.UTC_Plus 0;
      "Europe/Paris",         TZ.UTC_Plus 0;
      "America/Buenos_Aires", TZ.UTC_Plus 0;
      "America/Chicago",      TZ.UTC_Plus 0;
      "America/Detroit",      TZ.UTC_Plus 0;
      "America/Los_Angeles",  TZ.UTC_Plus 0;
      "America/Montreal",     TZ.UTC_Plus 0;
      "America/Sao_Paulo",    TZ.UTC_Plus 0;
      "Asia/Calcutta",        TZ.UTC_Plus 0;
      "Asia/Hong_Kong",       TZ.UTC_Plus 0;
      "Asia/Saigon",          TZ.UTC_Plus 0;
      "Asia/Shanghai",        TZ.UTC_Plus 0;
      "Asia/Singapore",       TZ.UTC_Plus 0;
      "Asia/Tokyo",           TZ.UTC_Plus 0;
      "Australia/Melbourne",  TZ.UTC_Plus 0;
      "Australia/Sydney",     TZ.UTC_Plus 0;
      "Brazil/East",          TZ.UTC_Plus 0;
      "CST6CDT",              TZ.UTC_Plus 0;
      "Canada/Pacific",       TZ.UTC_Plus 0;
      "EST",                  TZ.UTC_Plus 0;
      "EST5EDT",              TZ.UTC_Plus 0;
      "Europe/Berlin",        TZ.UTC_Plus 0;
      "Europe/Brussels",      TZ.UTC_Plus 0;
      "Europe/Bucharest",     TZ.UTC_Plus 0;
      "Europe/Copenhagen",    TZ.UTC_Plus 0;
      "Europe/Helsinki",      TZ.UTC_Plus 0;
      "Europe/Istanbul",      TZ.UTC_Plus 0;
      "Europe/Kiev",          TZ.UTC_Plus 0;
      "Europe/Lisbon",        TZ.UTC_Plus 0;
      "Europe/London",        TZ.UTC_Plus 0;
      "Europe/Madrid",        TZ.UTC_Plus 0;
      "Europe/Minsk",         TZ.UTC_Plus 0;
      "Europe/Moscow",        TZ.UTC_Plus 0;
      "Europe/Oslo",          TZ.UTC_Plus 0;
      "Europe/Rome",          TZ.UTC_Plus 0;
      "Europe/Stockholm",     TZ.UTC_Plus 0;
      "Europe/Tiraspol",      TZ.UTC_Plus 0;
      "Europe/Warsaw",        TZ.UTC_Plus 0;
      "Europe/Zagreb",        TZ.UTC_Plus 0;
      "Europe/Zurich",        TZ.UTC_Plus 0;
      "GB-Eire",              TZ.UTC_Plus 0;
      "Indian/Antananarivo",  TZ.UTC_Plus 0;
      "Japan",                TZ.UTC_Plus 0;
      "MST",                  TZ.UTC_Plus 0;
      "PST8PDT",              TZ.UTC_Plus 0;
      "Pacific/Easter",       TZ.UTC_Plus 0;
      "US/Central",           TZ.UTC_Plus 0;
      "US/Eastern",           TZ.UTC_Plus 0;
      "US/Pacific",           TZ.UTC_Plus 0;
      "Singapore",            TZ.UTC_Plus 0;
      "Chile/Continental",    TZ.UTC_Plus 0;
    ]
  in
  let of_string_map =
    List.fold_left 
      (fun mp (s,z) -> MapString.add s z mp)
      MapString.empty table
  in

  let of_string str =
    try 
      MapString.find str of_string_map 
    with Not_found ->
      TZ.UTC_Plus 0
(*
      failwith 
        (Printf.sprintf
           "Don't know what to do with timezone '%s'"
           str)
 *)
  in
    of_string

let to_string tz = 
  match tz with 
    | TZ.UTC -> 
        "+0000"
    | TZ.UTC_Plus n ->
        Printf.sprintf "%+02d00" n
    | TZ.Local ->
        Printf.sprintf "%+02d00" (TZ.gap TZ.UTC TZ.Local)
