(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

open Lwt
open XHTML.M
open Eliom_services
open Eliom_parameters
open Eliom_sessions
open Eliom_predefmod.Xhtml
open OCAAccount
open OCASession

let template ctnt =
  TemplateStub.make_page_stub
    ~page_title:"3rd party account management"
    []
    ctnt
    
(***********************************)

(** Services to display user's page account
  *)
let my_account ~ctxt base_path =
  register_new_service
    ~path:(base_path @ ["my_account"])
    ~get_params:(opt (string "redirect"))
    (fun sp uri_opt () ->
       return 
         (template
            [p 
               [pcdata 
                  "This page should display users's account page of \
                  http://forge.ocamlcore.org, but this is just a for test."]]))

(***********************************)

(* Services to manage an account
  *)
let manage_account ~ctxt base_path = 
  register_new_service 
    ~path:(base_path @ ["manage_account"])
    ~get_params:(opt (string "redirect"))
    (fun sp uri_opt () ->
       let ctnt = 
         [p 
            [pcdata "This page should display account as found on \
               http://forge.ocamlcore.org, but this is just a stub for test."];
          begin
            match uri_opt with 
              | Some uri ->
                  p
                    [XHTML.M.a 
                       ~a:[a_href (uri_of_string uri)]
                       [pcdata "Return to website"]]
              | None ->
                  p [pcdata "No link back to website"]
          end]
       in
         return (template ctnt))

(***********************************)

(** Services to create new account
  *)
let new_account ~ctxt base_path =
  register_new_service 
    ~path:(base_path @ ["new_account"])
    ~get_params:unit
    (fun sp () () ->
       return
         (template 
            [p 
               [pcdata 
                  "This page should display account creation of \
                  http://forge.ocamlcore.org, but this is just a stub for test. \
                  Use one of the fake account already created (no password required)."]]))

(***********************************)

(** Services to recover lost password
  *)
let lost_passwd ~ctxt base_path =
  register_new_service
    ~path:(base_path @ ["lost_passwd"])
    ~get_params:(opt (string "redirect"))
    (fun sp uri_opt () ->
       return 
         (template
            [p 
               [pcdata 
                  "This page should display password recovery procedure of \
                  http://forge.ocamlcore.org, but this is just a for test. \
                  No password are set on stub accounts."]]))
