(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

(** Test application for ocsigen/ocamlcore-api 
    @author Sylvain Le Gall
  *)

open Eliom_services
open Eliom_parameters
open XHTML.M
open Eliom_predefmod.Xhtml
open Lwt
open OCAWeb 
open Simplexmlparser

let ocaw_stub =
  OCAWeb.create ~stub:true ~base_path:["stub"] ()

let ocaw =
  [
    "from_config",
    OCAWeb.create_from_config ();
    
    "stub",
    ocaw_stub;

    "real",
    OCAWeb.create ();
  ]

let div_from_ocaw sp (nm, ctxt) = 
  catch 
    (fun () ->
       Session.action_box ~ctxt sp
       >>= fun sess_action_box ->
       Account.user_settings_box ~ctxt sp
       >|= fun accnt_user_settings_box ->
       div 
         [
           h1 [pcdata nm];
     
           h2 [pcdata "Account"];
     
           h3 [pcdata "user_settings_box"];
           accnt_user_settings_box; 

           h3 [pcdata "links"];
           ul
             (li [XHTML.M.a 
                    ~a:[a_href (Account.new_account ~ctxt sp)]
                    [pcdata "new account"]])
             [li [XHTML.M.a 
                    ~a:[a_href (Account.lost_passwd ~ctxt sp)]
                    [pcdata "lost passwd"]]];

     
           h2 [pcdata "Session"];
     
           h3 [pcdata "action_box"];
           sess_action_box;
         ])
    (fun e ->
       return 
         (div 
            [
              h1 [pcdata nm];
              
              pcdata "Not available";
            ]))

let _ = 
  let rec inter_hr =
    function
      | hd1 :: hd2 :: tl ->
          hd1 :: hr () :: (inter_hr (hd2 :: tl))
      | [_] | [] as e ->
          e
  in
    register_new_service
      ~path:[]
      ~get_params:unit
      (fun sp () () ->
         Lwt_list.map_s (div_from_ocaw sp) ocaw
         >>= fun lst ->
         return
           (Template.make_page
              ~ctxt:ocaw_stub
              ~website_title:"OCamlCore API"
              ~page_title:"tests"
              []
              (inter_hr lst)))
