(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

(* Test suite for ocamlcore-api *)

open Lwt
open OUnit

open OCAAccount

module TZ = CalendarLib.Time_Zone

let bracket_oca_context f = 
  bracket 
    (fun () ->
       let ctxt, stub_id = 
         OCAContext.create_stub ()
       in
         OCAStub.populate stub_id;
         ctxt)
    f
    ignore


let _ = 
  let tests = 
    "ocamlcore-api" >:::
    [
      "OCAAccount.list" >::
      (bracket_oca_context 
         (fun ctxt ->
            let lst = 
              Lwt_main.run (OCAAccount.list ~ctxt ())
            in
              assert_bool
                "List of account >0"
                (List.length lst > 0)));

      "OCAAccount.of_id" >::
      (bracket_oca_context
         (fun ctxt ->
            let uname = 
              (Lwt_main.run (OCAAccount.of_id ~ctxt 0)).accnt_unix_name
            in
              assert_equal
                ~printer:(fun s -> s)
                "admin1"
                uname));

      "OCAAccount.of_unix_id" >::
      (bracket_oca_context 
         (fun ctxt ->
            let uname = 
              (Lwt_main.run (OCAAccount.of_unix_id ~ctxt 20000)).accnt_unix_name
            in
              assert_equal
                ~printer:(fun s -> s)
                "admin1"
                uname));
    ]
  in

    run_test_tt_main tests

  (*
  OCASession.check ~ctxt 
    (OCASession.of_cookie 
      "MTAyLSotMTI5Nzk1MTEwNi0qLTgzLjE5OS4yNTUuODUtKi1Nb3ppbGxhLzUuMCAoWD\
       ExOyBVOyBMaW51eCB4ODZfNjQ7IGZyOyBydjoxLjkuMS4xNikgR2Vja28vMjAxMTAx\
       MDcgcHJvdXQgSWNld2Vhc2VsLzMuNS4xNiAobGlrZSBGaXJlZm94LzMuNS4xNik%3D\
       -%2A-8f5471e0265dd61558b43bc524eafb27")
  >>= fun b ->
  Lwt_io.printlf "Valid session: %b" b
   *)
